use std::env;

use anyhow::{bail, Result};
use dotenv::dotenv;

use crate::Chatbot;

/// Runs the chatbot
pub async fn run() -> Result<()> {
    dotenv().ok();

    let (user, password, homeserver, rooms) = match (
        env::var("CRIEUR_MATRIX_USER"),
        env::var("CRIEUR_MATRIX_PASSWORD"),
        env::var("CRIEUR_MATRIX_HOMESERVER"),
        env::var("CRIEUR_MATRIX_ROOMS"),
    ) {
        (Ok(user), Ok(password), Ok(homeserver), Ok(rooms)) => (
            user,
            password,
            homeserver,
            rooms
                .split(",")
                .map(|s| s.to_string())
                .collect::<Vec<String>>(),
        ),
        _ => bail!("Configuration incomplete, please set all required environment variables"),
    };

    let chatbot = Chatbot::builder()
        .login(&user, &password)
        .homeserver(&homeserver)
        .rooms(rooms)
        .connect()
        .await?;

    chatbot.run().await?;

    Ok(())
}
